@@ -20,12 +20,12 @@ Net::Amazon::DirectConnect - Perl interface to the Amazon DirectConnect API
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 DirectConnect API version 2012-10-25
 
 =cut
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 =head1 SYNOPSIS
 
@@ -217,7 +217,18 @@ sub _request {
     $req = $self->{sig}->sign($req);
 
     my $response = $self->ua->request($req);
-    croak __PACKAGE__ . sprintf('->_request: %s %s', decode_json($response->content)->{__type}, decode_json($response->content)->{message} || '') unless $response->is_success;
+    if (!$response->is_success) {
+
+        my $content = eval { decode_json($response->content) };
+        $content ||= {};
+
+        my $err_string = '';
+        $err_string .= $content->{__type} if $content->{__type};
+        $err_string .= ' ' . $content->{message} if $content->{message};
+        $err_string = $response->content unless $err_string;
+
+        croak __PACKAGE__ . sprintf('->_request: %s', $err_string);
+    }
 
     return $response;
 }
